/*******************************************************************
                      C O P Y R I G H T  (c) 1998
        F O C U S     A U T O M A T I O N   S Y S T E M S   I N C.
                          All Rights Reserved.
 -------------------------------------------------------------------

 config.c - Configuration reading/writing routines.

 -------------------------------------------------------------------
 *******************************************************************
 * $Source: $
 * $Date: $
 * $Revision: $
 *******************************************************************
*/

/* Standard headers */
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

/* Toolkit headers */
#include <Ph.h>
#include <Pt.h>
#include <Ap.h>

/* Local headers */
#include "abimport.h"
#include "proto.h"
#include "args.h"
#include "config.h"


static void parse_window_origin( char *buff );

struct
{
    char *name;
    void (*parser)( char *buff );
} ParseList[] =
{
    { "window_origin", &parse_window_origin },
    { NULL, NULL }
};


PhPoint_t WindowOrigin;


static void parse_window_origin( char *buff )
{
    sscanf( buff, "%*s = %hd %hd", &WindowOrigin.x, &WindowOrigin.y );

    return;
}


int read_config( int argc, char *argv[] )
{
    char *home;
    char  file[ PATH_MAX + 1 ];
    FILE *fp;

    argc = argc; argv = argv;

    parse_args( argc, argv );

    home = getenv( "HOME" );

    if ( home )
    {
        sprintf( file, "%s/.photon/.numpad", home );

        fp = fopen( file, "r" );
    }
    else
    {
        fp = NULL;
    }

    if ( fp )
    {
        char  buff[ 120 ];
        char  name[ 80 ];
        int   i;

        fgets( buff, sizeof( buff ), fp );

        while ( !feof( fp ) )
        {
            sscanf( buff, "%s", name );

            for ( i=0; ParseList[i].parser != NULL; i++ )
            {
                if ( !strcmp( name, ParseList[i].name ) )
                {
                    (*ParseList[i].parser)( buff );
                }
            }

            fgets( buff, sizeof( buff ), fp );
        }

        fclose( fp );
    }

    return( Pt_CONTINUE );
}


int write_config( PtWidget_t *widget,
                  ApInfo_t *apinfo,
                  PtCallbackInfo_t *cbinfo )
{
    char *home;
    char  file[ PATH_MAX + 1 ];
    FILE *fp;

    widget = widget, apinfo = apinfo, cbinfo = cbinfo;

    home = getenv( "HOME" );

    if ( home )
    {
        sprintf( file, "%s/.photon/.numpad", home );

        fp = fopen( file, "w" );
    }
    else
    {
        fp = NULL;
    }

    if ( fp )
    {
        fprintf( fp, "window_origin = %hd %hd\n", WindowOrigin.x,
                                                  WindowOrigin.y );
        fclose( fp );
    }

    return( Pt_CONTINUE );
}

