/*******************************************************************
                      C O P Y R I G H T  (c) 1998
        F O C U S     A U T O M A T I O N   S Y S T E M S   I N C.
                          All Rights Reserved.
 -------------------------------------------------------------------

 keypress.c - Callback functions for key presses.

 -------------------------------------------------------------------
 *******************************************************************
 * $Source: $
 * $Date: $
 * $Revision: $
 *******************************************************************
*/

/* Standard headers */
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <ctype.h>

/* Toolkit headers */
#include <Ph.h>
#include <Pt.h>
#include <Ap.h>
#include <photon/PkKeyDef.h>


/* Local headers */
#include "abimport.h"
#include "proto.h"
#include "input_group.h"
#include "args.h"


static void send_key( long key )
{
    PhEvent_t        event;
    PhRawKeyEvent_t  key_event;

    memset( &event    , 0, sizeof(event)     );
    memset( &key_event, 0, sizeof(key_event) );

    event.type          = Ph_EV_KEY;
    event.emitter.rid   = Ph_DEV_RID;
    event.data_len      = sizeof(key_event);
    event.input_group   = get_input_group( );

    key_event.key_cap   = key;
    key_event.key_sym   = key;

    if ( isascii( key ) && isupper( key ) )
    {
        key_event.key_mods = Pk_KM_Shift;
    }

    key_event.key_flags = Pk_KF_Sym_Valid | Pk_KF_Cap_Valid | Pk_KF_Key_Down;

    PhEventEmit( &event, NULL, &key_event );

    key_event.key_flags &= ~Pk_KF_Key_Down;

    PhEventEmit( &event, NULL, &key_event );

    return;
}


int keypress( PtWidget_t       *widget,
              ApInfo_t         *apinfo,
              PtCallbackInfo_t *cbinfo )
{
    PtArg_t  arg;
    char    *keyp;

    apinfo = apinfo, cbinfo = cbinfo;

    PtSetArg( &arg, Pt_ARG_TEXT_STRING, &keyp, NULL );
    PtGetResources( widget, 1, &arg );

    send_key( *keyp );

    return( Pt_CONTINUE );
}


int enter( PtWidget_t       *widget,
           ApInfo_t         *apinfo,
           PtCallbackInfo_t *cbinfo )
{
    widget = widget, apinfo = apinfo, cbinfo = cbinfo;

    send_key( Pk_Return );

    if ( OneShot )
    {
        PtDestroyWidget( ABW_base );
        exit( EXIT_SUCCESS );
    }

    return( Pt_CONTINUE );
}


int delete( PtWidget_t       *widget,
            ApInfo_t         *apinfo,
            PtCallbackInfo_t *cbinfo )
{
    widget = widget, apinfo = apinfo, cbinfo = cbinfo;

    send_key( Pk_Delete );

    return( Pt_CONTINUE );
}


int backspace( PtWidget_t       *widget,
               ApInfo_t         *apinfo,
               PtCallbackInfo_t *cbinfo )
{
    widget = widget, apinfo = apinfo, cbinfo = cbinfo;

    send_key( Pk_BackSpace );

    return( Pt_CONTINUE );
}


int left( PtWidget_t       *widget,
          ApInfo_t         *apinfo,
          PtCallbackInfo_t *cbinfo )
{
    widget = widget, apinfo = apinfo, cbinfo = cbinfo;

    send_key( Pk_Left );

    return( Pt_CONTINUE );
}


int right( PtWidget_t       *widget,
           ApInfo_t         *apinfo,
           PtCallbackInfo_t *cbinfo )
{
    widget = widget, apinfo = apinfo, cbinfo = cbinfo;

    send_key( Pk_Right );

    return( Pt_CONTINUE );
}

